@@ -6,52 +6,45 @@ package EPublisher::Source::Plugin::PerltutsCom;
 use strict;
 use warnings;
 
+use Data::Dumper;
 use Encode;
 use File::Basename;
-use HTTP::Tiny;
+use LWP::Simple;
 
-use parent qw( EPublisher::Source::Base );
+use EPublisher::Source::Base;
 
+our @ISA = qw( EPublisher::Source::Base );
 
-our $VERSION = '0.6_02';
-our $UA;
+our $VERSION = 0.2;
 
 # implementing the interface to EPublisher::Source::Base
 sub load_source{
-    my ($self, $name) = @_;
+    my ($self) = @_;
 
     $self->publisher->debug( '100: start ' . __PACKAGE__ );
 
     my $options = $self->_config;
     
-    $name //= $options->{name};
-    if ( !$name ) {
-        $self->publisher->debug( '400: No tutorial name given' );
-        return;
-    }
+    return '' unless $options->{name};
+
+    my $name = $options->{name};
 
     # fetching the requested tutorial from metacpan
     $self->publisher->debug( "103: fetch tutorial $name" );
 
-    return $self->_get_pod( $name );
-}
-
-sub _get_pod {
-    my ($self,$name) = @_;
-
-    my $response = $self->ua->get(
+    my $pod = LWP::Simple::get(
         'http://perltuts.com/tutorials/' . $name . '?format=pod'
     );
 
-    if ( $response->{status} !~ m{\A2} ) {
+    my $regex = qr/<div \s+ id="content" \s+ class="row"> .*? not \s+ found/;
+
+    if ( !$pod || $pod =~ $regex ) { 
         $self->publisher->debug(
             "103: tutorial $name does not exist"
         );
-
         return;
     };
 
-    my $pod = $response->{content};
 
     # perltuts.com always provides utf-8 encoded data, so we have
     # to decode it otherwise the target plugins may produce garbage
@@ -74,32 +67,25 @@ sub _get_pod {
         "103: passed info: "
         . "filename => $name, "
         . "title => $title, "
-        . 'pod => ' . substr($pod, 0, 30) . '<<<<CUT<<<<'
+        . "pod => $pod"
     );
 
     return @pod;
 }
 
-sub ua {
-    $UA = HTTP::Tiny->new if !$UA;
-    $UA;
-}
-
 1;
 
+
 __END__
-
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 EPublisher::Source::Plugin::PerltutsCom - Get POD from tutorials published on perltuts.com
 
 =head1 VERSION
 
-version 0.6_02
+version 0.2
 
 =head1 SYNOPSIS
 
@@ -107,13 +93,7 @@ version 0.6_02
   my $url_source     = EPublisher::Source->new( $source_options );
   my $pod            = $url_source->load_source;
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item ua
-
-=back
+=encoding utf-8
 
 =head1 METHODS
 
@@ -136,3 +116,4 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
